from setuptools import setup, find_packages

setup(
    name="ANBUtils",
    version="1.5.5",
    packages=find_packages(),
    author="redbson",
    author_email="redbson@gmail.com",
    python_requires='>=3.8',
    install_requires=[
        "matplotlib>=3.0.0",
        "numpy>=1.0.0",
        "pandas>=1.0.0",
        "pymongo>=4.0.2",
        "requests>=2.0.0",
        "matplotlib>=3.0.0",

    ]
)
